<?php
/**
 * Plugin Name: Non WebP Upload Blocker
 * Description: Ce plugin bloque le téléversement d'images qui ne sont pas au format webp et qui dépassent 300 Ko.
 * Version: 1.1
 * Author: Christophe de Cherche Un Pro Formations
 */

// Sécurité : si ce fichier est appelé directement, exit.
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

// Ajouter un filtre pour l'action 'wp_handle_upload_prefilter'
add_filter( 'wp_handle_upload_prefilter', 'non_webp_upload_blocker' );

function non_webp_upload_blocker( $file ) {
    $allowed_types = array( 'image/webp' );
    $max_file_size = 300 * 1024; // 300 Ko en octets

    // Vérifier si le fichier est une image
    $is_image = getimagesize( $file['tmp_name'] );

    if ( $is_image ) {
        // Vérifier la taille du fichier
        if ( $file['size'] > $max_file_size ) {
            // Supprimer le fichier trop volumineux
            unlink( $file['tmp_name'] );

            // Retourner une erreur à l'utilisateur
            $file['error'] = 'Désolé, les images doivent faire 300 Ko maximum.';
            return $file;
        }

        // Récupérer le type MIME du fichier téléversé
        $mime_type = mime_content_type( $file['tmp_name'] );

        // Vérifier si le type MIME n'est pas autorisé pour les images
        if ( in_array( $mime_type, $allowed_types ) ) {
            return $file; // Autoriser le téléversement
        } else {
            // Supprimer le fichier non autorisé
            unlink( $file['tmp_name'] );
            
            // Retourner une erreur à l'utilisateur
            $file['error'] = 'Désolé, seules les images au format webp sont autorisées.';
            return $file;
        }
    }

    return $file; // Autoriser le téléversement pour les fichiers non image
}
?>
